ConsoleFormatter class
Default LogFormatter for console output.
Split string into multiline, prettify output.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
LogEvent event) → String -
formatLevel(
LogLevel level) → String -
formatStackTrace(
StackTrace? trace) → StackTrace? -
formatTime(
DateTime time) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited